aboutsummaryrefslogtreecommitdiff
path: root/src/backend/tcop/postgres.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/tcop/postgres.c')
-rw-r--r--src/backend/tcop/postgres.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/backend/tcop/postgres.c b/src/backend/tcop/postgres.c
index c01cff9d650..5655348a2e2 100644
--- a/src/backend/tcop/postgres.c
+++ b/src/backend/tcop/postgres.c
@@ -310,7 +310,7 @@ InteractiveBackend(StringInfo inBuf)
printf("statement: %s\n", inBuf->data);
fflush(stdout);
- return 'Q';
+ return PqMsg_Query;
}
/*
@@ -4897,9 +4897,9 @@ PostgresMain(const char *dbname, const char *username)
break;
/*
* 'X' means that the frontend is closing down the socket. EOF
* means unexpected loss of frontend connection. Either way,
* perform normal shutdown.
*/
case EOF:
@@ -4897,9 +4897,9 @@ PostgresMain(const char *dbname, const char *username)
break;
/*
- * 'X' means that the frontend is closing down the socket. EOF
- * means unexpected loss of frontend connection. Either way,
- * perform normal shutdown.
+ * PqMsg_Terminate means that the frontend is closing down the
+ * socket. EOF means unexpected loss of frontend connection.
+ * Either way, perform normal shutdown.
*/
case EOF: